@@ -29,7 +29,7 @@ sys.path.append("/usr/lib/asterisk-phonepatch")
 import templateparser, dtmf, radio
 import radiocontrol, daemonize
 
-__version__ = "$Revision: 1.9 $"
+__version__ = "$Revision: 1.10 $"
 __author__ = "Arnau Sanchez <arnau@ehas.org>"
 __depends__ = ['Asterisk', 'Sox', 'Festival', 'Python-2.4']
 __copyright__ = """Copyright (C) 2006 Arnau Sanchez <arnau@ehas.org>.
@@ -459,8 +459,7 @@ class Phonepatch:
 				except: pass
 				if option[0] == self.festival_indicator:
 					self.raw_buffer += self.play_text(option[len(self.festival_indicator):])
-				else:
-					self.raw_buffer += self.play_file(option)
+				else: self.raw_buffer += self.play_file(option)
 			# If something went wrong, raw_buffer will have no data
 			if not self.raw_buffer: 
 				self.debug("play: audio buffer is empty, giving up audio play")
@@ -954,7 +953,8 @@ class Phonepatch:
 			self.phonepatch_extension = None
 			if mode == "dtmf": self.debug("loop_daemon: waiting askfortone DTMF button: %s" %button)
 			if self.ctcss_decoder: self.debug("loop_daemon: CTCSS decoding enabled")
-			# CTCSS decoding always done (as it can be enabled inside an extension
+			self.radio.clear_ctcss()
+			# CTCSS decoding always done (as it can be enabled inside an extension)
 			# DTMF decoding only if asked globally
 			while 1:
 				if self.sleep_signal:
@@ -990,7 +990,7 @@ class Phonepatch:
 			# AskForTone DTMF button received, now record the destination number
 			# TODO: Fullduplex
 			self.play(True, False, self.getconf("tone_audio"), max_time=self.getconf("tone_audio_time"), loop=True)
-			self.debug("loop_daemon: waiting for number and outcall_buttony")
+			self.debug("loop_daemon: waiting for number and outcall_button")
 			timeout_time = time.time() + self.getconf("tone_timeout")
 			dtmf_keys = []
 		
