@@ -26,7 +26,7 @@ import struct
 # External phonepatch modules
 import soundcard, ctcss
 
-__version__ = "$Revision: 1.8 $"
+__version__ = "$Revision: 1.10 $"
 __author__ = "Arnau Sanchez <arnau@ehas.org>"
 __depends__ = ['Python-2.4']
 __copyright__ = """Copyright (C) 2006 Arnau Sanchez <arnau@ehas.org>.
@@ -143,10 +143,15 @@ class Radio:
 	def decode_ctcss(self, buffer):
 		if not self.ctcss_decoder: return
 		self.ctcss_decoder.decode_buffer(buffer)
+
+	#####################################
+	def clear_ctcss(self):
+		if not self.ctcss_decoder: return
+		self.ctcss_decoder.clear_tone()
 		
 	#####################################
 	def get_ctcss_tone(self):
-		#return 200.0 # test
+		#return 200.0
 		if not self.ctcss_decoder: return
 		return self.ctcss_decoder.get_tone()
 		
